# **********************************************************************
# Copyright 2018 VMware, Inc.  All rights reserved. VMware Confidential.
# **********************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# **********************************************************************

from collections import namedtuple
import nsx_logging
import json

import cli.commands.host_shared.ovs_util as ovs_util

from cli.commands.cli_command_provider import CliCommandProvider


lg = nsx_logging.getLogger("cli.commands.host_kvm.switch_security")

class HostGetSpoofGuardStatsSummary(CliCommandProvider):
    def __call__(self, cmd_list):
        result_map = {}
        res = ovs_util.get_spoofguard_stats(cmd_list[3])
        for stats in res:
            arr = stats.split(':')
            result_map[arr[0].strip()] = arr[1].strip()
        return "OK\n\n%s" % json.dumps(result_map)


class HostGetSwitchSecurityStatsSummary(CliCommandProvider):
    def __call__(self, cmd_list):
        result_map = {}
        res = ovs_util.get_switchsecurity_stats(cmd_list[3])
        for stats in res:
            arr = stats.split(':')
            result_map[arr[0].strip()] = arr[1].strip()
        return "OK\n\n%s" % json.dumps(result_map)


class HostGetSpoofGuardWhitelistSummary(CliCommandProvider):
    def __call__(self, cmd_list):
        result_list = []
        WLEntry = namedtuple("WLEntry", "ip mac vlan")
        res = ovs_util.get_spoofguard_whitelist(cmd_list[3])
        for wl in res:
            entry = WLEntry(ip=wl[3], mac=wl[2], vlan=wl[4])
            result_list.append(entry)
        return "OK\n\n%s" % json.dumps(result_list)


class HostGetSwitchSecurityConfigSummary(CliCommandProvider):
    def __call__(self, cmd_list):
        result_map = {}
        res = ovs_util.get_switchsecurity_config(cmd_list[3])
        if res:
            config = res[0]
            result_map['BPDU Filter'] = config[7]
            result_map['DHCPv4 Client Block'] = config[3]
            result_map['DHCPv4 Server Block'] = config[4]
            result_map['DHCPv6 Client Block'] = config[5]
            result_map['DHCPv6 Server Block'] = config[6]
            result_map['Non-IP Traffic Block'] = config[8]
            result_map['RA Guard'] = config[2]
        return "OK\n\n%s" % json.dumps(result_map)


class HostGetSpoofGuardConfigSummary(CliCommandProvider):
    def __call__(self, cmd_list):
        result_map = {}
        res = ovs_util.get_switchsecurity_config(cmd_list[3])
        if res:
            config = res[0]
            result_map['Switch Spoof Guard'] = config[8]
            result_map['Port Spoof Guard'] = config[1]
        return "OK\n\n%s" % json.dumps(result_map)
