# **********************************************************************
# Copyright 2017 VMware, Inc.  All rights reserved. VMware Confidential.
# **********************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# **********************************************************************
import nsx_logging
import json

from cli.commands.cli_command_provider import CliCommandProvider
from cli.commands.lcp_common.cfgagent.client import get_cfgagent_cli_output

lg = nsx_logging.getLogger("cli.commands.lcp_common.cfgagent.cfgagent")


def load_response_output(response):
    try:
        if response is None:
            return None
        output = json.loads(response)
    except (TypeError, ValueError) as err:
        lg.error("load response error: %s", err,
                 error_code=ec.INTERNAL_ERROR)
        return None
    return output

class GetCfgagentLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get/loglevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        log_level = cmd_list[4]
        response = get_cfgagent_cli_output("cfgagent/set/loglevel", [log_level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentWFTTraceLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get-wft/tracelevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentWFTTraceLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        wft_level = cmd_list[5]
        response = get_cfgagent_cli_output("cfgagent/set-wft/tracelevel", [wft_level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentWFTLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get-wft/loglevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentWFTLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        wft_level = cmd_list[5]
        response = get_cfgagent_cli_output("cfgagent/set-wft/loglevel", [wft_level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentLogicalSwitchPortStatus(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/lport/status")
        if response is None:
            return "MSG_CFGAGENT_LOGICAL_SWITCH_PORT_STATUS_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentMetricsLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get-metrics/loglevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentMetricsLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        log_level = cmd_list[5]
        response = get_cfgagent_cli_output("cfgagent/set-metrics/loglevel", [log_level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentNetLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get-net/loglevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentNetLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        log_level = cmd_list[5]
        response = get_cfgagent_cli_output("cfgagent/set-net/loglevel", [log_level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentRpcLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get-rpc/loglevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentRpcLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        log_level = cmd_list[5]
        response = get_cfgagent_cli_output("cfgagent/set-rpc/loglevel", [log_level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentNestDbLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get-nestdb/loglevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentNestDbLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        log_level = cmd_list[5]
        response = get_cfgagent_cli_output("cfgagent/set-nestdb/loglevel", [log_level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentHyperBusVmknics(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/hyperbusvmk")
        output = load_response_output(response)
        if response is None:
            return "MSG_CFGAGENT_CONFIG_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentSegmentPortStatus(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/lport/status")
        if response is None:
            return "MSG_CFGAGENT_SEGMENT_PORT_STATUS_FAILED"
        mapping = {
            "Logical Port": "Segment Port",
            "Logical Switch": "Segment"
        }
        header = response.split("\n")[0]
        for key, value in list(mapping.items()):
            header = header.replace(key, value)
        response = "\n".join([header] + response.split("\n")[1:])

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentLSPExtraConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/lsp/extracfg")
        output = load_response_output(response)
        if response is None:
            return "MSG_CFGAGENT_CONFIG_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentLSExtraConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/ls/extracfg")
        output = load_response_output(response)
        if response is None:
            return "MSG_CFGAGENT_CONFIG_FAILED"

        return "OK\n\n%s" % json.dumps(output)

class GetCfgagentShaClientLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get-sha/loglevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentShaClientLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        level = cmd_list[5]
        response = get_cfgagent_cli_output("cfgagent/set-sha/loglevel", [level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentHyperBusLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get-hyperbus/loglevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentHyperBusLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        level = cmd_list[5]
        response = get_cfgagent_cli_output("cfgagent/set-hyperbus/loglevel", [level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class GetCfgagentUpmLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/get-upm/loglevel")
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)


class SetCfgagentUpmLogLevel(CliCommandProvider):
    def __call__(self, cmd_list):
        level = cmd_list[5]
        response = get_cfgagent_cli_output("cfgagent/set-upm/loglevel", [level])
        if response is None:
            return "MSG_CFGAGENT_LOG_LEVEL_FAILED"

        return "OK\n\n%s" % json.dumps(response)
