# Copyright (C) 2021 VMware, Inc. All rights reserved.
# -- VMware Confidential
import sys

CLI_REQ_ID = 'id'
CLI_REQ_CMD = 'cmd'
CLI_REQ_ARGS = 'args'
CLI_RESP_ERR_CODE = 'err_code'
CLI_RESP_ERR_DESC = 'err_desc'
CLI_RESP_RESULT = 'result'


CLI_REQ_HELP = 'help'
CLI_RESP_HELP_DESC = 'summary'
CLI_RESP_HELP_OPTIONS = 'options'
CLI_RESP_HELP_OPTION_NAME = 'name'
CLI_RESP_HELP_OPTION_VALUE = 'value'
CLI_RESP_HELP_OPTION_REQUIRED = 'required'
CLI_RESP_HELP_OPTION_DESC = 'description'


CLI_SERVER_WORKERS = 5
CLI_SERVER_PIPE_MAGIC = b'\xc6'


if sys.platform != 'win32':
    CLI_SERVICE_SOCKET = '/var/run/vmware/nsx-sha/sha_cli_srv.sock'
    CLI_CONTROL_SOCKET = '/var/run/vmware/nsx-sha/sha_cli_ctl.sock'
else:
    CLI_SERVICE_SOCKET = ('127.0.0.1', 15349)
    CLI_CONTROL_SOCKET = ('127.0.0.1', 15359)


class CommandRequest:

    def __init__(self, id_, cmd, args):
        self._id = id_
        self._cmd = cmd
        self._args = {} if args is None else args

    def payload(self):
        data = {
            CLI_REQ_ID: self._id,
            CLI_REQ_CMD: self._cmd
        }
        if self._args:
            data[CLI_REQ_ARGS] = self._args
        return data


class CommandResponse:

    def __init__(self, result, err_code, err_desc):
        self._result = result
        self._err_code = err_code
        self._err_desc = err_desc

    def payload(self):
        data = {
            CLI_RESP_ERR_CODE: self._err_code
        }
        if self._result:
            data[CLI_RESP_RESULT] = self._result
        if self._err_desc:
            data[CLI_RESP_ERR_DESC] = self._err_desc
        return data
